@@ -1,6 +1,6 @@
 from django.urls import include, path
 
 urlpatterns = [
-    path("bread/", include("bread.urls")),
+    path("basxbread/", include("basxbread.urls")),
     path("basxconnect/", include("basxconnect.core.urls")),
 ]
